"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const system_settings_1 = require("@ewizardjs/system-settings");
const globby_1 = __importDefault(require("globby"));
const path_1 = require("path");
const webpack_merge_1 = __importDefault(require("webpack-merge"));
exports.default = async (config, options) => {
    const layoutsConfig = await getLayoutsConfig(config, options);
    return webpack_merge_1.default(config, layoutsConfig);
};
const getLayoutsConfig = async (config, options) => {
    const { layout } = options;
    if (!layout) {
        return {};
    }
    const alias = await buildAliases(config.context, layout);
    return {
        resolve: {
            alias,
        },
    };
};
async function buildAliases(contextPath, layout) {
    const layoutsDirName = await system_settings_1.getByPath(contextPath, 'path.layouts');
    const layoutPath = path_1.join(contextPath, `${layoutsDirName}/${layout}`);
    const layoutFilesList = await globby_1.default('**', {
        cwd: layoutPath,
        dot: true,
    });
    if (layoutFilesList.length) {
        return layoutFilesList.reduce((acc, file) => {
            acc[`${path_1.resolve(contextPath, file)}`] = path_1.resolve(`${layoutPath}/${file}`);
            return acc;
        }, {});
    }
    console.log(`Layout ${layoutPath} not exists!`);
    process.exit(1);
}
//# sourceMappingURL=webpack.config.js.map