"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const builder_utils_1 = require("@ewizardjs/builder-utils");
const plugins_1 = require("@ewizardjs/builder-utils/plugins");
const rules_1 = require("@ewizardjs/builder-utils/rules");
const settings_1 = require("@ewizardjs/settings");
const path_1 = require("path");
const webpack_merge_1 = __importDefault(require("webpack-merge"));
const get_entry_common_loader_1 = __importDefault(require("../../get-entry-common-loader"));
const content_type_loader_1 = require("../../loaders/content-type-loader");
const InjectCommonChunksPlugin_1 = __importDefault(require("../../plugins/InjectCommonChunksPlugin"));
const ResetStatePlugin_1 = __importDefault(require("../../plugins/ResetStatePlugin"));
const webpack_config_1 = __importDefault(require("../bubbles/webpack.config"));
exports.default = async (options) => {
    const baseConfig = await webpack_config_1.default(options);
    const { presentationPath, systemSettings } = options;
    const currentThemeName = await settings_1.getCurrentTheme(presentationPath);
    const themesList = await builder_utils_1.getThemesList(presentationPath, systemSettings.path.themesManifest, systemSettings.path.themes);
    const uniqueBlocksList = await builder_utils_1.containsDynamicBlocksLoader(presentationPath, systemSettings.path.rootComponent) ?
        builder_utils_1.getCurrentBlocks(presentationPath, systemSettings) :
        [];
    const cornConfig = {
        entry: {
            app: [require.resolve('../../../assets/entry-common'), options.appEntryPath],
            index: options.indexEntryPath,
            editor: require.resolve('../../../assets/entry-editor'),
        },
        optimization: {
            splitChunks: {
                hidePathInfo: true,
                cacheGroups: {
                    common: {
                        name: 'common',
                        chunks: 'all',
                        minSize: 1310720,
                        maxSize: 5242880,
                        minChunks: 2,
                    },
                },
            },
        },
        module: {
            rules: [
                ...content_type_loader_1.getContentTypeLoader({
                    include: /node_modules/,
                }),
                get_entry_common_loader_1.default(options.presentationPath),
                rules_1.currentTheme({
                    options: {
                        presentationPath,
                        currentTheme: currentThemeName,
                        themes: themesList,
                    },
                }),
                rules_1.currentBlocks({
                    options: {
                        blocksList: uniqueBlocksList,
                    },
                }),
            ],
        },
        output: {
            library: ['Content', '[name]'],
            jsonpFunction: 'ewizardjsJsonp',
        },
        externals: {
            './app': {
                commonjs: ['Content', 'app'],
                commonjs2: ['Content', 'app'],
                root: ['Content', 'app'],
            },
        },
        plugins: [
            new ResetStatePlugin_1.default(options.presentationPath),
            new InjectCommonChunksPlugin_1.default({
                live: options.live,
                watch: options.watch,
            }),
            plugins_1.cleanDestinationFolder(options.presentationPath, path_1.join(options.presentationPath, 'build', 'dev')),
        ],
    };
    return webpack_merge_1.default.strategy({
        entry: 'replace',
        externals: 'replace',
        'output.library': 'replace',
        'module.rules': 'prepend',
    })(baseConfig, cornConfig);
};
//# sourceMappingURL=webpack.config.js.map